@@ -15,6 +15,7 @@ from swagger_coverage.src.files import FileOperation
 from swagger_coverage.src.prepare_data import PrepareData
 from swagger_coverage.src.utils import to_dict, merge_results
 
+
 logger = logging.getLogger("swagger")
 
 
@@ -103,34 +104,34 @@ class SwaggerCoverage(metaclass=Singleton):
     def create_results_from_json(path: str = None):
         # Load data from json files
         parent_dir = os.path.abspath(os.path.abspath(os.curdir))
-        path_to_results = os.path.join(parent_dir, "report", "json_results")
+        path_to_results = os.path.join(parent_dir, "swagger_report", "json_results")
         get_all_files = list(pathlib.Path(path_to_results).glob("*.json"))
-        results = merge_results(get_all_files)
+        results, summary_dict = merge_results(get_all_files)
         api_url = results.get("api_url")
         swagger_url = results.get("swagger_url")
-        summary_dict = results.get("data").get("summary")
+        # summary_dict = results.get("data").get("summary")
         if not path:
             path = results.get("path")
         summary_class = (
             EndpointStatisticsHtml(
-                endpoints=summary_dict[0].get("endpoints"),
-                checked_endpoints=summary_dict[0].get("checked_endpoints"),
-                not_checked_endpoints=summary_dict[0].get("not_checked_endpoints"),
-                not_added_endpoints=summary_dict[0].get("not_added_endpoints"),
+                endpoints=summary_dict[0].endpoints,
+                checked_endpoints=summary_dict[0].checked_endpoints,
+                not_checked_endpoints=summary_dict[0].not_checked_endpoints,
+                not_added_endpoints=summary_dict[0].not_added_endpoints,
             ),
             PercentStatistic(
-                summary_dict[1].get("success"), summary_dict[1].get("failed")
-            ),
-        )
+                summary_dict[1].success, summary_dict[1].failed)
+            )
         data_class = SwaggerData(
             swagger_data=results.get("data").get("swagger_data"),
             diff=results.get("data").get("diff"),
-            summary=summary_class,
+            summary=summary_class
         )
         reporter = ReportHtml(
             path=path, api_url=api_url, swagger_url=swagger_url, data=data_class
         )
         reporter.save_html()
+        return data_class
 
     def save_results(self, path: str = None):
         """
