@@ -278,7 +278,7 @@ class ReportHtml:
             )
             table_body.append(f'<th scope="col">{count + 1}</th>\n')
             table_body.append(f'<th scope="col">{res.get("name")}</th>\n')
-            table_body.append(f'<th scope="col">{res.get("results")}</th>\n')
+            table_body.append(f'<th scope="col">{str(res.get("results"))[:5]}</th>\n')
             table_body.append("</tr>\n")
             table_body.append("</thead>\n")
         return "".join(table_body)
@@ -315,7 +315,7 @@ class ReportHtml:
             desc = "-"
 
         avg_execution = value.get("time_executions")
-        if avg_execution is None:
+        if avg_execution is None or len(avg_execution) == 0:
             summery_time_exc = "-"
         else:
             summery_time_exc = sum(avg_execution) / len(avg_execution)
